@@ -42,6 +42,8 @@ pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
 pub use self::error_detail::ErrorDetail;
+pub mod event_model;
+pub use self::event_model::EventModel;
 pub mod event_source;
 pub use self::event_source::EventSource;
 pub mod event_status;
@@ -204,6 +206,8 @@ pub mod patched_janus_auth_request;
 pub use self::patched_janus_auth_request::PatchedJanusAuthRequest;
 pub mod patched_octo_print_device_request;
 pub use self::patched_octo_print_device_request::PatchedOctoPrintDeviceRequest;
+pub mod patched_polymorphic_event_request;
+pub use self::patched_polymorphic_event_request::PatchedPolymorphicEventRequest;
 pub mod patched_print_session_request;
 pub use self::patched_print_session_request::PatchedPrintSessionRequest;
 pub mod patched_printer_controller_request;
@@ -216,6 +220,8 @@ pub mod patched_remote_control_command_request;
 pub use self::patched_remote_control_command_request::PatchedRemoteControlCommandRequest;
 pub mod patched_system_info_request;
 pub use self::patched_system_info_request::PatchedSystemInfoRequest;
+pub mod patched_test_event_request;
+pub use self::patched_test_event_request::PatchedTestEventRequest;
 pub mod patched_user_request;
 pub use self::patched_user_request::PatchedUserRequest;
 pub mod polymorphic_event;
